@@ -3,11 +3,11 @@ try:
     from CTL.causal_tree.util_c import *
 except:
     from CTL.causal_tree.util import *
-from CTL.causal_tree.causal_tree import *
+from CTL.causal_tree.ct import *
 import numpy as np
 
 
-class CausalTreeLearnNode(CausalTreeNode):
+class CTLearnNode(CTNode):
 
     def __init__(self, p_val=1.0, effect=0.0, node_depth=0, control_mean=0.0, treatment_mean=0.0, col=-1, value=-1,
                  is_leaf=False, leaf_num=-1, num_samples=0.0, obj=0.0):
@@ -36,7 +36,7 @@ class CausalTreeLearnNode(CausalTreeNode):
         self.decision = ""
 
 
-class CausalTreeLearn(CausalTree):
+class CTLearn(CausalTree):
 
     def __init__(self, weight=0.5, split_size=0.5, max_depth=-1, min_size=2, seed=724, feature_batch_size=None,
                  magnitude=True, honest=False, max_values=None, verbose=False):
@@ -59,7 +59,7 @@ class CausalTreeLearn(CausalTree):
 
         self.honest = honest
 
-        self.root = CausalTreeLearnNode()
+        self.root = CTLearnNode()
 
     @abstractmethod
     def fit(self, x, y, t):
@@ -225,7 +225,7 @@ class CausalTreeLearn(CausalTree):
 
     def predict(self, x):
 
-        def _predict(node: CausalTreeLearnNode, observation):
+        def _predict(node: CTLearnNode, observation):
             if node.is_leaf:
                 return node.effect
             else:
@@ -253,7 +253,7 @@ class CausalTreeLearn(CausalTree):
 
     def get_groups(self, x):
 
-        def _get_group(node: CausalTreeLearnNode, observation):
+        def _get_group(node: CTLearnNode, observation):
             if node.is_leaf:
                 return node.leaf_num
             else:
@@ -278,7 +278,7 @@ class CausalTreeLearn(CausalTree):
 
     def get_features(self, x):
 
-        def _get_features(node: CausalTreeLearnNode, observation, features):
+        def _get_features(node: CTLearnNode, observation, features):
             if node.is_leaf:
                 return features
             else:
@@ -306,7 +306,7 @@ class CausalTreeLearn(CausalTree):
 
     def prune(self, alpha=0.05):
 
-        def _prune(node: CausalTreeLearnNode):
+        def _prune(node: CTLearnNode):
             if node.true_branch is None or node.false_branch is None:
                 return
 
