@@ -2,7 +2,7 @@ from CTL.causal_tree.ctl.binary_ctl import *
 from sklearn.model_selection import train_test_split
 
 
-class BaseCausalTreeLearnNode(CausalTreeLearnNode):
+class BaseCausalTreeLearnNode(CTLearnNode):
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
@@ -13,7 +13,7 @@ class BaseCausalTreeLearnNode(CausalTreeLearnNode):
 # ----------------------------------------------------------------
 # Base causal tree (ctl, base objective)
 # ----------------------------------------------------------------
-class CausalTreeLearnBase(CausalTreeLearn):
+class CausalTreeLearnBase(CTLearn):
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
@@ -37,7 +37,7 @@ class CausalTreeLearnBase(CausalTreeLearn):
         # ----------------------------------------------------------------
         train_x, val_x, train_y, val_y, train_t, val_t = train_test_split(x, y, t, random_state=self.seed, shuffle=True,
                                                                           test_size=self.val_split)
-        self.root.num_samples = y.shape[0]
+        self.root.num_samples = train_y.shape[0]
         # ----------------------------------------------------------------
         # effect and pvals
         # ----------------------------------------------------------------
