@@ -10,12 +10,15 @@ from CTL.causal_tree.ctl_trigger.ctl_honest_trigger import *
 from CTL.causal_tree.ctl_trigger.ctl_val_honest_trigger import *
 from CTL.causal_tree.ctl_trigger.honest_trigger import *
 
+from CTL._tree import _CausalTree
 
-class CausalTree:
+
+class CausalTree(_CausalTree):
 
     def __init__(self, cont=False, val_honest=False, honest=False, min_size=2, max_depth=-1, split_size=0.5, weight=0.5,
                  seed=724, quartile=False, old_trigger_code=False, feature_batch_size=None, magnitude=True,
                  max_values=None, verbose=False):
+        super().__init__()
         self.cont = cont
 
         params = {
@@ -192,7 +195,7 @@ class CausalTree:
                                 show_samples=show_samples, show_effect=show_effect, trigger_precision=trigger_precision)
             dot_file.write("}")
 
-    def _tree_to_dot_r(self, node: CausalTreeLearnNode, features, dot_file, counter, alpha=0.5, show_pval=True,
+    def _tree_to_dot_r(self, node: CTLearnNode, features, dot_file, counter, alpha=0.5, show_pval=True,
                        show_samples=True,
                        show_effect=True, trigger_precision=2):
 
@@ -264,36 +267,49 @@ class CausalTree:
         color_idx = 0
         effect = node.effect
         eps = 0.01
-        if np.abs(effect) <= eps:
-            color = "white"
+        if self.tree.max_effect > 1 or self.tree.min_effect < -1:
+            effect_range = np.linspace(self.tree.min_effect, self.tree.max_effect, 10)
+            for idx, effect_r in enumerate(effect_range[:-1]):
+                if effect_range[idx] <= effect <= effect_range[idx + 1]:
+                    # color = "\"/blues9/%i\"" % (idx + 1)
+                    # rdbu9
+                    color = "\"/rdbu9/%i\"" % (idx + 1)
+                    color_idx = idx
+                    break
+            if color_idx >= 8:
+                font_color = ", fontcolor=white"
+                node_str.append(font_color)
         else:
-            if effect > 0:
-                # effect_range = np.linspace(0, self.max, 10)
-                effect_range = np.linspace(0, 1, 10)
-                for idx, effect_r in enumerate(effect_range[:-1]):
-                    if effect_range[idx] <= effect <= effect_range[idx + 1]:
-                        color = "\"/blues9/%i\"" % (idx + 1)
-                        color_idx = idx
-                        break
-                if color_idx >= 8:
-                    font_color = ", fontcolor=white"
-                    node_str.append(font_color)
+            if np.abs(effect) <= eps:
+                color = "white"
             else:
-                # effect_range = np.linspace(self.min, 0, 10)
-                effect_range = np.linspace(-1, 0, 10)[::-1]
-                for idx, effect_r in enumerate(effect_range[:-1]):
-                    # if effect_range[idx] >= effect >= effect_range[idx + 1]:
-                    #         color = "\"/reds9/%i\"" % (idx + 1)
-                    #         color_idx = idx
-                    #         break
-                    # if effect <= effect_range[idx] and effect >= effect_range[idx+1]:
-                    if effect_range[idx + 1] <= effect <= effect_range[idx]:
-                        color = "\"/reds9/%i\"" % (idx + 1)
-                        color_idx = idx
-                        break
-                if color_idx >= 8:
-                    font_color = ", fontcolor=white"
-                    node_str.append(font_color)
+                if effect > 0:
+                    # effect_range = np.linspace(0, self.max, 10)
+                    effect_range = np.linspace(0, 1, 10)
+                    for idx, effect_r in enumerate(effect_range[:-1]):
+                        if effect_range[idx] <= effect <= effect_range[idx + 1]:
+                            color = "\"/blues9/%i\"" % (idx + 1)
+                            color_idx = idx
+                            break
+                    if color_idx >= 8:
+                        font_color = ", fontcolor=white"
+                        node_str.append(font_color)
+                else:
+                    # effect_range = np.linspace(self.min, 0, 10)
+                    effect_range = np.linspace(-1, 0, 10)[::-1]
+                    for idx, effect_r in enumerate(effect_range[:-1]):
+                        # if effect_range[idx] >= effect >= effect_range[idx + 1]:
+                        #         color = "\"/reds9/%i\"" % (idx + 1)
+                        #         color_idx = idx
+                        #         break
+                        # if effect <= effect_range[idx] and effect >= effect_range[idx+1]:
+                        if effect_range[idx + 1] <= effect <= effect_range[idx]:
+                            color = "\"/reds9/%i\"" % (idx + 1)
+                            color_idx = idx
+                            break
+                    if color_idx >= 8:
+                        font_color = ", fontcolor=white"
+                        node_str.append(font_color)
 
         color_str = ", fillcolor=" + color
         node_str.append(color_str)
@@ -353,7 +369,7 @@ class CausalTree:
 
         variable_names = col_dict(feature_names)
 
-        def _assign_feature_names(node: CausalTreeLearnNode, feat_names):
+        def _assign_feature_names(node: CTLearnNode, feat_names):
 
             if not node.is_leaf:
                 sz_col = 'Column %s' % node.col
@@ -393,7 +409,7 @@ class CausalTree:
             if variable_names is not None:
                 self.assign_feature_names(feature_names=variable_names)
 
-        def _get_variables(node: CausalTreeLearnNode, list_vars, list_depths):
+        def _get_variables(node: CTLearnNode, list_vars, list_depths):
 
             # print(node.is_leaf, node.true_branch, node.false_branch)
             if node.is_leaf:
